Module driver

Module driver 

AnimationDriver — owns and ticks multiple animations simultaneously.

Structs

AnimationDriver
Manages a collection of animations, ticking them each frame and automatically removing completed ones.
AnimationId
An opaque handle to an animation registered with AnimationDriver.
AnimationUpdateCost
Per-animation update cost produced by AnimationDriver::tick_profiled.
DriverFrameProfile
Timing data produced by a profiled driver tick.
DriverSnapshot
Snapshot of one inspectable animation registered with AnimationDriver.